@@ -12,7 +12,7 @@ use File::Path qw( mkpath rmtree );
 use IPC::Run 'run';
 use Text::Diff ();
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 sub init {
     die "Project already initialized\n" if ( -d '.dest' );
@@ -155,10 +155,19 @@ sub diff {
 
 sub update {
     my $self  = shift;
-    my @paths = @_;
 
     die "Not in project root directory or project not initialized\n" unless ( -d '.dest' );
 
+    my @paths   = @_;
+    my @watches = $self->_watches;
+
+    if (@paths) {
+        @watches = grep {
+            my $watch = $_;
+            grep { $_ eq $watch } @paths;
+        } @watches;
+    }
+
     File::DirCompare->compare( ".dest/$_", $_, sub {
         my ( $a, $b ) = @_;
         return if ( $a and $a =~ /\/dest.wrap$/ or $b and $b =~ /\/dest.wrap$/ );
@@ -186,12 +195,7 @@ sub update {
                 $self->dircopy( $a, ".dest/$a" );
             }
         }
-    } ) for (
-        grep {
-            my $watch = $_;
-            grep { $_ eq $watch } @paths;
-        } $self->_watches()
-    );
+    } ) for (@watches);
 
     return 0;
 }
@@ -361,7 +365,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -387,6 +391,7 @@ dest COMMAND [DIR || NAME]
     dest revdeploy NAME  # revert and deployment of a specific action
     dest update [DIRS]   # automaticall deploy or revert to cause currency
 
+    dest version         # dest current version
     dest help            # display command synposis
     dest man             # display man page
 
@@ -585,6 +590,10 @@ you have two tracked directories and limit the update to only one directory and
 within the directory there is an action with a dependency on an action in the
 non-specificied directory, that action will be triggered.
 
+=head2 version
+
+Displays the current dest version.
+
 =head2 help
 
 Displays a synposis of commands and their usage.
@@ -678,6 +687,14 @@ L<Travis CI|https://travis-ci.org/gryphonshafer/dest>
 
 L<Coveralls|https://coveralls.io/r/gryphonshafer/dest>
 
+=item *
+
+L<CPANTS|http://cpants.cpanauthors.org/dist/App-Dest>
+
+=item *
+
+L<CPAN Testers|http://www.cpantesters.org/distro/A/App-Dest.html>
+
 =back
 
 =head1 AUTHOR
